#pylint: disable=C0103

from ansi.sequence import sequence


# Cursor movement
up          = sequence('A')
down        = sequence('B')
forward     = sequence('C')
back        = sequence('D')
next_line   = sequence('E')
prev_line   = sequence('F')
goto_x      = sequence('G')
goto        = sequence('H', 2)
erase       = sequence('J')
erase_data  = erase
erase_line  = sequence('K')
scroll_up   = sequence('S')
scroll_down = sequence('T')
save_cursor = sequence('s')
load_cursor = sequence('u')



CSI = '\x1b['


def sequence(letter, fields=1, default=[]):
    def _sequence(*values):
        output = list(values)
        if fields >= 0 and len(output) > fields:
            raise ValueError('Invalid number of fields, got %d expected %d' %
                (len(output), fields))

        while len(output) < fields and len(default) > len(output):
            output.append(fields[len(default) - 1])

        return ''.join([
            CSI,
            ';'.join(map(str, output)),
            letter,
        ])

    return _sequence



#pylint: disable=C0103,R0903

from ansi.colour.base import Graphic
from ansi.colour.fx import bold


# ECMA-048 standard names
black           = Graphic('30')
red             = Graphic('31')
green           = Graphic('32')
yellow          = Graphic('33')
blue            = Graphic('34')
magenta         = Graphic('35')
cyan            = Graphic('36')
white           = Graphic('37')
default         = Graphic('39')

# ECMA-048 bold variants
boldblack       = bold + black
boldred         = bold + red
boldgreen       = bold + green
boldyellow      = bold + yellow
boldblue        = bold + blue
boldmagenta     = bold + magenta
boldcyan        = bold + cyan
boldwhite       = bold + white

# High intensity variants
brightblack     = Graphic('90')
brightred       = Graphic('91')
brightgreen     = Graphic('92')
brightyellow    = Graphic('93')
brightblue      = Graphic('94')
brightmagenta   = Graphic('95')
brightcyan      = Graphic('96')
brightwhite     = Graphic('97')

# Convenience wrappers
brown           = yellow                # Not in ANSI/ECMA-048 standard
grey            = white                 # Not in ANSI/ECMA-048 standard
gray            = white                 # US English
darkgrey        = boldblack
darkgray        = boldblack             # US English
brightbrown     = boldyellow            # Not in ANSI/ECMA-048 standard
brightgrey      = boldwhite             # Not in ANSI/ECMA-048 standard
brightgray      = boldwhite             # Us English



#pylint: disable=C0103,R0903

from ansi.colour.base import Graphic


# ECMA-048 standard names
reset            = Graphic('0')
bold             = Graphic('1')
faint            = Graphic('2')
italic           = Graphic('3')
underline        = Graphic('4')
blink_slow       = Graphic('5')
blink            = Graphic('6')
negative         = Graphic('7')
conceal          = Graphic('8')
crossed_out      = Graphic('9')
font_reset       = Graphic('10')
font_1           = Graphic('11')
font_2           = Graphic('12')
font_3           = Graphic('13')
font_4           = Graphic('14')
font_5           = Graphic('15')
font_6           = Graphic('16')
font_7           = Graphic('17')
font_8           = Graphic('18')
font_9           = Graphic('19')
fraktur          = Graphic('20')
gothic           = Graphic('20')
underline_double = Graphic('21')
normal           = Graphic('22')
not_italic       = Graphic('23')
not_fraktur      = Graphic('23')
not_gothic       = Graphic('23')
not_underline    = Graphic('24')
steady           = Graphic('25')
positive         = Graphic('27')
reveal           = Graphic('28')
framed           = Graphic('51')
encircled        = Graphic('52')
overlined        = Graphic('53')
not_framed       = Graphic('54')
not_encircled    = Graphic('54')
not_overlined    = Graphic('55')

# Convenience wrappers
inverse          = negative
bright           = bold
not_blink        = steady
blink_off        = steady



#!/usr/bin/env python

from distutils.core import setup

setup(name='ansi',
      version='0.1.5',
      description='ANSI cursor movement and graphics',
      author='Wijnand Modderman-Lenstra',
      author_email='maze@pyth0n.org',
      url='https://github.com/tehmaze/ansi/',
      packages = ['ansi', 'ansi.colour'],
      long_description='''
ANSI
====

Various ANSI escape codes, used in moving the cursor in a text console or
rendering coloured text.


Example
-------

Print something in bold yellow on a red background::

    >>> from ansi.colour import fg, bg, reset
    >>> print map(str, [bg.red, fg.yellow, 'Hello world!', reset])
    ...

If you like syntactic sugar, you may also do::

    >>> print bg.red(fg.yellow('Hello world!'))
    ...

Also, 256 RGB colors are supported::

    >>> from ansi.colour import rgb, reset
    >>> print rgb(0xff, 0x80, 0x00) + 'hello world' + reset
    ...

If you prefer to use American English in stead::

    >>> from ansi.color import ...
''')



#pylint: disable=C0103,R0903

from ansi.sequence import sequence
from ansi._compat import string_types


__all__ = ['Graphic']


class Graphic(object):
    '''
    Compose a Select Graphic Rendition (SGR) ANSI escape sequence.
    '''

    def __init__(self, *values):
        self.values = values
        self.sequence = sequence('m', fields=-1)(*values)

    def __add__(self, their):
        if isinstance(their, str):
            return ''.join([str(self), their])
        elif isinstance(their, string_types):
            raise ValueError('Use str, nothing else.')
        else:
            return Graphic(*(self.values + their.values))

    def __call__(self, text, reset=True):
        result = self.sequence + text
        if reset:
            result += str(Graphic('0'))
        return result

    def __str__(self):
        return self.sequence
